pytilities.overloading.matchers — Pytilities v1.0.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities v1.0.0 documentation »
- API documentation »
- pytilities »
- pytilities.overloading »

# pytilities.overloading.matchers

`pytilities.overloading.matchers.` `matches_all`(*matchers)

  A matcher that matches values which match all given matchers matchers: – collection of matcher functions

`pytilities.overloading.matchers.` `matches_any`(*matchers)

  A matcher that matches values which are instances of any of given types matchers: – ordered sequence of matcher functions

`pytilities.overloading.matchers.` `matches_everything`(value)

  A matcher that always returns true

`pytilities.overloading.matchers.` `matches_none`(*matchers)

  A matcher that matches values which are instances of any of given types matchers: – collection of matcher functions

`pytilities.overloading.matchers.` `matches_type`(*types)

  A matcher that matches values which are instances of any of given types types: – collection of types

### Navigation

- index
- modules |
- next |
- previous |
- Pytilities v1.0.0 documentation »
- API documentation »
- pytilities »
- pytilities.overloading »